@@ -33,7 +33,7 @@ from docker.types import LogConfig, Mount
 from dotenv import dotenv_values
 
 from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException, AirflowSkipException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
 from airflow.models import BaseOperator
 from airflow.providers.docker.hooks.docker import DockerHook
 
@@ -159,6 +159,10 @@ class DockerOperator(BaseOperator):
     :param skip_on_exit_code: If task exits with this exit code, leave the task
         in ``skipped`` state (default: None). If set to ``None``, any non-zero
         exit code will be treated as a failure.
+    :param port_bindings: Publish a container's port(s) to the host. It is a
+        dictionary of value where the key indicates the port to open inside the container
+        and value indicates the host port that binds to the container port.
+        Incompatible with ``host`` in ``network_mode``.
     """
 
     template_fields: Sequence[str] = ("image", "command", "environment", "env_file", "container_name")
@@ -217,6 +221,7 @@ class DockerOperator(BaseOperator):
         ipc_mode: str | None = None,
         skip_exit_code: int | None = None,
         skip_on_exit_code: int | Container[int] | None = None,
+        port_bindings: dict | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -224,7 +229,7 @@ class DockerOperator(BaseOperator):
         if type(auto_remove) == bool:
             warnings.warn(
                 "bool value for auto_remove is deprecated, please use 'never', 'success', or 'force' instead",
-                DeprecationWarning,
+                AirflowProviderDeprecationWarning,
                 stacklevel=2,
             )
         if str(auto_remove) == "False":
@@ -280,7 +285,9 @@ class DockerOperator(BaseOperator):
         self.ipc_mode = ipc_mode
         if skip_exit_code is not None:
             warnings.warn(
-                "skip_exit_code is deprecated. Please use skip_on_exit_code", DeprecationWarning, stacklevel=2
+                "skip_exit_code is deprecated. Please use skip_on_exit_code",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
             )
             skip_on_exit_code = skip_exit_code
 
@@ -291,6 +298,9 @@ class DockerOperator(BaseOperator):
             if skip_on_exit_code
             else []
         )
+        self.port_bindings = port_bindings or {}
+        if self.port_bindings and self.network_mode == "host":
+            raise ValueError("Port bindings is not supported in the host network mode")
 
     @cached_property
     def hook(self) -> DockerHook:
@@ -357,6 +367,7 @@ class DockerOperator(BaseOperator):
             command=self.format_command(self.command),
             name=self.container_name,
             environment={**env_file_vars, **self.environment, **self._private_environment},
+            ports=list(self.port_bindings),
             host_config=self.cli.create_host_config(
                 auto_remove=False,
                 mounts=target_mounts,
@@ -365,6 +376,7 @@ class DockerOperator(BaseOperator):
                 dns=self.dns,
                 dns_search=self.dns_search,
                 cpu_shares=int(round(self.cpus * 1024)),
+                port_bindings=self.port_bindings,
                 mem_limit=self.mem_limit,
                 cap_add=self.cap_add,
                 extra_hosts=self.extra_hosts,
